@@ -16,8 +16,7 @@ class AccountsSettings : public KQuickAddons::ConfigModule
     Q_OBJECT
 
 public:
-    explicit AccountsSettings(QObject *parent, const QVariantList &args);
-    ~AccountsSettings() override = default;
+    explicit AccountsSettings(QObject *parent, const KPluginMetaData &data, const QVariantList &args);
 };
 
 #endif // ACCOUNTSSETTINGS_H
